@@ -410,6 +410,16 @@
                 @$db->updatequery("ALTER TABLE `imei_db` ADD UNIQUE ( `imei` ) ");
                 @$db->updatequery("update `system` set `version`='113'");
         }
+	@$db->updatequery("ALTER TABLE `sim` ADD `month_remain_time` INT NOT NULL DEFAULT '-1'");
+	@$db->updatequery("ALTER TABLE `sim` ADD `month_limit_time` INT NOT NULL DEFAULT '-1'");
+	@$db->updatequery("ALTER TABLE `sim` ADD `month_reset_day` INT NOT NULL DEFAULT '1'");
+	@$db->updatequery("ALTER TABLE `sim` ADD `month_last_reset_time` timestamp NOT NULL default CURRENT_TIMESTAMP");
+/* 1.10-t1 set IMEI befor bind when IMEI MODE=IMEI-IMSI datebase */
+/* 1.10-t2 add simnum*/
+	@$db->updatequery("ALTER TABLE `sim` ADD `simnum` VARCHAR( 32 ) NOT NULL");
+/* 1.10-t3 fixed bug of dial in api.php */
+/* 1.11 fixed bug of period time*/
+
 	echo "update done! <a href=''  target=_top>Return</a>";
 
 ?>
